@@ -90,14 +90,7 @@ def dmsstr2deg(s: str) -> float:
     result = s.split(':')
     if len(result) != 3:
         raise ValueError(f'Illegal DMS string: {s}')
-
-    try:
-        return dms2deg(int(result[0]), int(result[1]), float(result[2]), sign)
-    except ValueError:
-        import logging
-        logging.error(f'Uhoh: {s}')
-        raise
-
+    return dms2deg(int(result[0]), int(result[1]), float(result[2]), sign)
 
 def dms2deg(d: int, m: int, s: float, sign: str) -> float:
     """Degrees, minutes, seconds to decimal degrees
