@@ -1,3 +1,10 @@
+# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
+
+"""This will have to be customized by a given observatory if used independently
+    of Gemini.
+"""
+
 from enum import Enum
 from typing import Optional
 
@@ -6,11 +13,12 @@ import pytz
 
 
 class Site(Enum):
-    """
-    The sites belonging to the observatory using the Scheduler.
+    """The sites belonging to the observatory using the Scheduler.
+
+    Attributes:
+        GN: Gemini North (568@399)
+        GS: Gemini South (I11@399)
 
-    This will have to be customized by a given observatory if used independently
-    of Gemini.
     """
     GN = ('Gemini North', '568@399')
     GS = ('Gemini South', 'I11@399')
@@ -36,4 +44,4 @@ class Site(Enum):
             raise ValueError(e, msg)
 
 
-ALL_SITES = frozenset(s for s in Site)
+ALL_SITES = frozenset(s for s in Site)  # A variable to work with all the sites in scheduler components.
